Test coverage report: frequently.models

# frequently.models: 3 total statements, 100.0% covered

Generated: Fri 2012-09-28 15:02 CEST

Source file: /Users/martin/Repos/django-frequently/frequently/models.py

Stats: 2 executed, 0 missed, 1 excluded, 7 ignored

1. `"""`
2. `Models for the ``django-frequently`` application.`
3. ``
4. `"""`
5. `from django.db import models`
6. ``
7. ``
8. `class Example(models.Model):`
9. `"""Example model class."""`
10. `text = models.TextField(blank=True, null=True)`